|PyPI| |Python| |License| |Travis| |AppVeyor| |ReadTheDocs| |Coverage|

mpi4pyd: MPI for Python Dummies
===============================


.. |PyPI| image:: https://img.shields.io/pypi/v/mpi4pyd.svg?label=PyPI
    :target: https://pypi.python.org/pypi/mpi4pyd
    :alt: PyPI - Latest Release
.. |Python| image:: https://img.shields.io/pypi/pyversions/mpi4pyd.svg?logo=python&logoColor=white&label=Python
    :target: https://pypi.python.org/pypi/mpi4pyd
    :alt: PyPI - Python Versions
.. |License| image:: https://img.shields.io/pypi/l/mpi4pyd.svg?colorB=blue&label=License
    :target: https://github.com/1313e/mpi4pyd/raw/master/LICENSE
    :alt: PyPI - License
.. |Travis| image:: https://img.shields.io/travis/com/1313e/mpi4pyd/master.svg?logo=travis%20ci&logoColor=white&label=Travis%20CI
    :target: https://travis-ci.com/1313e/mpi4pyd
    :alt: Travis CI - Build Status
.. |AppVeyor| image:: https://img.shields.io/appveyor/ci/1313e/mpi4pyd/master.svg?logo=appveyor&logoColor=white&label=AppVeyor
    :target: https://ci.appveyor.com/project/1313e/mpi4pyd/branch/master
    :alt: AppVeyor - Build Status
.. |ReadTheDocs| image:: https://img.shields.io/readthedocs/mpi4pyd/latest.svg?logo=read%20the%20docs&logoColor=white&label=Docs
    :target: https://mpi4pyd.readthedocs.io/en/latest
    :alt: ReadTheDocs - Build Status
.. |Coverage| image:: https://img.shields.io/codecov/c/github/1313e/mpi4pyd/master.svg?logo=codecov&logoColor=white&label=Coverage
    :target: https://codecov.io/gh/1313e/mpi4pyd/branches/master
    :alt: CodeCov - Coverage Status